From 608c02b186d5a47c3ec90eb6d8eb8d22ca3aa1c0 Mon Sep 17 00:00:00 2001
From: Tails developers <tails@boum.org>
Date: Mon, 2 Jun 2014 00:30:33 +0200
Subject: [PATCH 5/9] Speed up some private data access

Avoid all unnecessary uses of G_TYPE_INSTANCE_GET_PRIVATE() as it is a
*lot* slower than direct object->priv access.
---
 src/task-item.c  | 2 +-
 src/task-list.c  | 2 +-
 src/task-title.c | 4 ++--
 3 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/task-item.c b/src/task-item.c
index 25acb7a..3370bc3 100644
--- a/src/task-item.c
+++ b/src/task-item.c
@@ -712,7 +712,7 @@ static void task_item_setup_atk (TaskItem *item) {
 }
 
 static void task_item_finalize (GObject *object) {
-    TaskItemPrivate *priv = TASK_ITEM_GET_PRIVATE (object);
+    TaskItemPrivate *priv = TASK_ITEM (object)->priv;
     /* remove timer */
     if (priv->timer) {
         g_source_remove (priv->timer);
diff --git a/src/task-list.c b/src/task-list.c
index 52d2a7c..cc1864e 100644
--- a/src/task-list.c
+++ b/src/task-list.c
@@ -90,7 +90,7 @@ static void on_window_opened (WnckScreen *screen,
 
 /* GObject stuff */
 static void task_list_finalize (GObject *object) {
-    TaskListPrivate *priv = TASK_LIST_GET_PRIVATE (object);
+    TaskListPrivate *priv = TASK_LIST (object)->priv;
     /* Remove the blink timer */
     if (priv->timer) g_source_remove (priv->timer);
     G_OBJECT_CLASS (task_list_parent_class)->finalize (object);
diff --git a/src/task-title.c b/src/task-title.c
index 9b0117b..b646b8f 100644
--- a/src/task-title.c
+++ b/src/task-title.c
@@ -271,7 +271,7 @@ static void on_active_window_changed (WnckScreen *screen,
  */
 static gboolean on_button_press (GtkWidget *title, GdkEventButton *event) {
     g_return_val_if_fail (TASK_IS_TITLE (title), FALSE);
-    TaskTitlePrivate *priv = TASK_TITLE_GET_PRIVATE (title);
+    TaskTitlePrivate *priv = TASK_TITLE (title)->priv;
     WnckWindow *window = wnck_screen_get_active_window (priv->screen);
     g_return_val_if_fail (WNCK_IS_WINDOW (window), FALSE);
 
@@ -452,7 +452,7 @@ static void task_title_init (TaskTitle *title) {
 /* Destructor for the task title*/
 static void task_title_finalize (GObject *object) {
     TaskTitlePrivate *priv;
-    priv = TASK_TITLE_GET_PRIVATE (object);
+    priv = TASK_TITLE (object)->priv;
     disconnect_window (TASK_TITLE (object));
     g_object_unref (G_OBJECT (priv->quit_icon));
     G_OBJECT_CLASS (task_title_parent_class)->finalize (object);
-- 
2.0.0.rc4

